## Text Editor
This is a program written in tkinter which acts as text editor.This can be used to edit file
### Steps to Download textEditor
```
pip install textEditor
```
### How to use it?
```
import textEditor
```

### About The Author
I am Devesh Sharma.I read in class 9. I live in samalkha,panipat located in India.

